<?php
/**
 * Register meta boxes
 *
 * @since 1.0
 *
 * @param array $meta_boxes
 *
 * @return array
 */
function hera_register_meta_boxes( $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_cmb_';

	// Post format
	$meta_boxes[] = array(
		'id'       => 'format_detail',
		'title'    => esc_html__( 'Format Details', 'hera' ),
		'pages'    => array( 'post' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name'             => esc_html__( 'Image', 'hera' ),
				'id'               => $prefix . 'image',
				'type'             => 'image_advanced',
				'class'            => 'image',
				'max_file_uploads' => 1,
			),
			array(
				'name'  => esc_html__( 'Gallery', 'hera' ),
				'id'    => $prefix . 'images',
				'type'  => 'image_advanced',
				'class' => 'gallery',
			),
			array(
				'name'  => esc_html__( 'Quote', 'hera' ),
				'id'    => $prefix . 'quote',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'quote',
			),
			array(
				'name'  => esc_html__( 'Author', 'hera' ),
				'id'    => $prefix . 'quote_author',
				'type'  => 'text',
				'class' => 'quote',
			),			
			array(
				'name'  => esc_html__( 'Audio', 'hera' ),
				'id'    => $prefix . 'link_audio',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'audio',
				'desc' => 'Ex: https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/139083759',
			),
			array(
				'name'  => esc_html__( 'Video', 'hera' ),
				'id'    => $prefix . 'link_video',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'video',
				'desc' => 'Example: <b>http://www.youtube.com/embed/0ecv0bT9DEo</b> or <b>http://player.vimeo.com/video/47355798</b>',
			),	
		),
	);	
	
    $meta_boxes[] = array(
        'id'         => 'page_setting',
        'title'      => esc_html__( 'Page Setting', 'hera' ),
        'pages'      => array('page'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
        	array(
                'name' => esc_html__( 'Upload Background Image Top', 'hera' ),
                'desc' => '',
                'id' => $prefix . 'bg_page',
                'type'             => 'image_advanced',				
				'max_file_uploads' => 1,
            ),                 
            array(
                'name' => esc_html__( 'Page SubTitle', 'hera' ),
                'desc' => esc_html__( 'Set Page SubTitle, use for template blog, template default, template full width.', 'hera' ),
                'id'   => $prefix . 'page_subtitle',
                'type'  => 'WYSIWYG',
            ),                                      
        )
    );

	$meta_boxes[] = array(
        'id'         => 'history_setting',
        'title'      => esc_html__( 'History Setting', 'hera' ),
        'pages'      => array('history'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
        	array(
                'name' => esc_html__( 'Upload Background Image Top', 'hera' ),
                'desc' => '',
                'id' => $prefix . 'bg_page',
                'type'             => 'image_advanced',				
				'max_file_uploads' => 1,
            ),                               
        )
    );

	// Add other metaboxes as needed	
    $meta_boxes[] = array(
        'id'         => 'portfolio_setting',
        'title'      => esc_html__( 'Portfolio Setting', 'hera' ),
        'pages'      => array('portfolio'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array( 
        	array(
				'name'  => esc_html__( 'Video', 'hera' ),
				'id'    => $prefix . 'link_video',
				'type'  => 'text',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'video',
				'desc' => 'Example: <b>http://www.youtube.com/watch?v=QgnRut8Qloc</b> or <b>https://player.vimeo.com/video/8159394</b>',
			),	                      
            array(
                'name' => esc_html__( 'SubTitle', 'hera' ),
                'desc' => '',
                'id'   => $prefix . 'folio_stitle',
                'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
            ),                 
        )
    );
	// Add other metaboxes as needed
	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'hera_register_meta_boxes' );

/**
 * Enqueue scripts for admin
 *
 * @since  1.0
 */
function hera_admin_enqueue_scripts( $hook ) {
	// Detect to load un-minify scripts when WP_DEBUG is enable
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	if ( in_array( $hook, array( 'post.php', 'post-new.php' ) ) ) {
		wp_enqueue_script( 'hera-backend-js', get_template_directory_uri()."/js/admin.js", array( 'jquery' ), '1.0.0', true );
	}
}

add_action( 'admin_enqueue_scripts', 'hera_admin_enqueue_scripts' );
