<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "hera_option";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'opt_name' => 'hera_option',
        'use_cdn' => TRUE,
        'display_name'     => $theme->get('Name'),
        'display_version'  => $theme->get('Version'),
        'page_title' => 'Hera Options',
        'update_notice' => FALSE,
        'admin_bar' => TRUE,
        'menu_type' => 'menu',
        'menu_title' => 'Hera Options',
        'allow_sub_menu' => TRUE,
        'page_parent_post_type' => 'your_post_type',
        'customizer' => TRUE,
        'dev_mode'   => false,
        'default_mark' => '*',
        'hints' => array(
            'icon_position' => 'right',
            'icon_color' => 'lightgray',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'page_priority' => 90,
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'database' => 'options',
        'transient_time' => '3600',
        'network_sites' => TRUE,
    );

    Redux::set_args( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Theme Information 1', 'hera' ),
            'content' => esc_html__( 'This is the tab content, HTML is allowed.', 'hera' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_html__( 'Theme Information 2', 'hera' ),
            'content' => esc_html__( 'This is the tab content, HTML is allowed.', 'hera' )
        )
    );
    Redux::set_help_tab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_html__( 'This is the sidebar content, HTML is allowed.', 'hera' );
    Redux::set_help_sidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    // ACTUAL DECLARATION OF SECTIONS
    Redux::set_section( $opt_name, array(
        'icon' => 'el-icon-cogs',
        'title' => __('General Settings', 'hera'),
        'fields' => array(  
            array(
                'id'   =>'divider_1',
                'desc' => __('Animation Settings', 'hera'),
                'type' => 'divide'
            ),  
            array(
                'id'       => 'show_animation',
                'type'     => 'switch', 
                'title'    => __('Scroll Animation Off?', 'hera'),
                'subtitle' => __('Look, it\'s on!', 'hera'),
                'default'  => true,
            ),  
            array(
                'id'   =>'divider_2',
                'desc' => __('Preload Settings', 'hera'),
                'type' => 'divide'
            ),                                                       
            array(
                'id'       => 'show_pre',
                'type'     => 'switch', 
                'title'    => __('Preload Off?', 'hera'),
                'subtitle' => __('Look, it\'s on!', 'hera'),
                'default'  => true,
            ),  
            array(
                'id' => 'logopre',
                'type' => 'media',
                'url' => false,
                'title' => __('Logo Preload', 'hera'),
                'compiler' => 'true',                
                'desc' => __('Upload your logo preload.', 'hera'),
                'subtitle' => __('Recommended size: Max Height: 60px and Width: 200px', 'hera'),
                'default' => array('url' => get_template_directory_uri().'/images/logo-preload.png'),
            ),        
            array(
                'id' => 'prelogo_width',
                'type' => 'text',
                'title' => __('Fix Width Logo scroll down page, Default: 150', 'hera'),
                'subtitle' => __('Input Width logo', 'hera'),                        
                'default' => ''
            ),  
            array(
                'id' => 'prelogo_height',
                'type' => 'text',
                'title' => __('Fix Height Logo scroll down page, Default: 60', 'hera'),
                'subtitle' => __('Input Height Logo', 'hera'),                        
                'default' => ''
            ),                
            array(
                'id' => 'preload_color',
                'type' => 'color',
                'title' => __('Preload number percentage text color', 'hera'),
                'subtitle' => __('Pick a number percentage text color for the preload (default: #ffffff).', 'hera'),
                'default' => '#ffffff',
                'validate' => 'color',
            ),
            array(
                'id' => 'background_preload',
                'type' => 'color',
                'title' => __('Preload Background Color', 'hera'),
                'subtitle' => __('Pick a background color for the preload (default: #000).', 'hera'),
                'default' => '#000',
                'validate' => 'color',
            ),  
            array(
                'id' => 'gmap_api',
                'type' => 'text',
                'title' => __('Google Map API Key', 'hera'),
                'subtitle' => __('Add your Google map api key here, find Google map API key here: https://developers.google.com/maps/documentation/javascript/', 'hera'),                        
                'default' => 'AIzaSyAvpnlHRidMIU374bKM5-sx8ruc01OvDjI'
            ),                   
        )
    ) );

    Redux::set_section( $opt_name, array(
        'icon' => ' el-icon-picture',
        'title' => __('Logo & Favicon Settings', 'hera'),
        'fields' => array(
            array(
                'id' => 'favicon',
                'type' => 'media',
                'url' => false,
                'title' => __('Custom Favicon', 'hera'),
                'compiler' => 'true',                
                'desc' => __('Upload your Favicon.', 'hera'),
                'subtitle' => __('', 'hera'),
                'default' => array('url' => get_template_directory_uri().'/images/favicon.png'),
            ),                    
            array(
                'id' => 'logo',
                'type' => 'media',
                'url' => false,
                'title' => __('Logo', 'hera'),
                'compiler' => 'true',                
                'desc' => __('Upload your logo.', 'hera'),
                'subtitle' => __('Recommended size: Max Height: 60px and Width: 200px', 'hera'),
                'default' => array('url' => get_template_directory_uri().'/images/logo-dark.png'),
            ),   
            array(
                'id'   =>'divider_1',
                'desc' => __('Please fixed Width & Height for Logo static.', 'hera'),
                'type' => 'divide'
            ),
            array(
                'id' => 'logo_width',
                'type' => 'text',
                'title' => __('Fix Width Logo static, Default: 200', 'hera'),
                'subtitle' => __('Input Width logo, remember enter number.', 'hera'),                        
                'default' => ''
            ),  
            array(
                'id' => 'logo_height',
                'type' => 'text',
                'title' => __('Fix Height Logo static, Default: 80', 'hera'),
                'subtitle' => __('Input Height Logo, remember enter number.', 'hera'),                        
                'default' => ''
            ),     
            array(
                'id' => 'logo_margin',
                'type' => 'text',
                'title' => __('Fix margin Top for Logo Scroll, Default: 10', 'hera'),
                'subtitle' => __('Input Width logo, remember enter number.', 'hera'),                        
                'default' => ''
            ), 
            array(
                'id'   =>'divider_2',
                'desc' => __('Please fixed Width & Height for Logo scroll.', 'hera'),
                'type' => 'divide'
            ),
            array(
                'id' => 'logos_width',
                'type' => 'text',
                'title' => __('Fix Width Logo Scroll, Default: 150', 'hera'),
                'subtitle' => __('Input Width logo, remember enter number.', 'hera'),                        
                'default' => ''
            ),  
            array(
                'id' => 'logos_height',
                'type' => 'text',
                'title' => __('Fix Height Logo Scroll, Default: 60', 'hera'),
                'subtitle' => __('Input Height Logo, remember enter number.', 'hera'),                        
                'default' => ''
            ),                        
            array(
                'id'   =>'divider_3',
                'desc' => __('Please fixed Width & Height for Logo display on mobile devices.', 'hera'),
                'type' => 'divide'
            ),
            array(
                'id' => 'logo_width_mobile',
                'type' => 'text',
                'title' => __('Fix Width Logo on mobile devices, Default: 150', 'hera'),
                'subtitle' => __('Input Width logo', 'hera'),
                'default' => ''
            ),  
            array(
                'id' => 'logo_height_mobile',
                'type' => 'text',
                'title' => __('Fix Height Logo on mobile devices, Default: 60', 'hera'),
                'subtitle' => __('Input Height Logo', 'hera'),                        
                'default' => ''
            ),  
            array(
                'id' => 'apple_icon',
                'type' => 'media',
                'url' => false,
                'title' => __('Apple Touch Icon 57x57', 'hera'),
                'compiler' => 'true',                
                'desc' => __('Upload your Apple touch icon 57x57.', 'hera'),
                'subtitle' => __('', 'hera'),
                'default' => array('url' => get_template_directory_uri().'/images/apple-touch-icon.png'),
            ),                  
            array(
                'id' => 'apple_icon_72',
                'type' => 'media',
                'url' => false,
                'title' => __('Apple Touch Icon 72x72', 'hera'),
                'compiler' => 'true',                
                'desc' => __('Upload your Apple touch icon 72x72.', 'hera'),
                'subtitle' => __('', 'hera'),
                'default' => array('url' => get_template_directory_uri().'/images/apple-touch-icon-72x72.png'),
            ),
            array(
                'id' => 'apple_icon_114',
                'type' => 'media',
                'url' => false,
                'title' => __('Apple Touch Icon 114x114', 'hera'),
                'compiler' => 'true',                
                'desc' => __('Upload your Apple touch icon 114x114.', 'hera'),
                'subtitle' => __('', 'hera'),
                'default' => array('url' => get_template_directory_uri().'/images/apple-touch-icon-114x114.png'),
            ),                  
        )
    ) );
    Redux::set_section( $opt_name, array(
        'icon' => 'el-icon-qrcode',
        'title' => __('Header Settings', 'hera'),
        'fields' => array( 
            array(
                'id' => 'header_layout',
                'type' => 'image_select',
                'title' => __('Header Layout', 'hera'),
                'subtitle' => __('Select Your Header layout', 'hera'),
                'desc' => '',
                'options' => array(
                    'header1' => array(
                        'alt'   => 'Hlayout 1',
                        'img'   => get_template_directory_uri().'/images/hlayout1.png'
                    ),
                    'header2' => array(
                        'alt'   => 'Hlayout 2',
                        'img'   => get_template_directory_uri().'/images/hlayout2.png'
                    ),     
                    'header_showcase' => array(
                        'alt'   => 'Header Showcase',
                        'img'   => get_template_directory_uri().'/images/menu-showcase.png '
                    ),                                                 
                ), 
                'default' => 'header1'
            ),                                      
            array(
                'id' => 'menu_text',
                'type' => 'text',
                'title' => __('Button Menu Title', 'hera'),
                'subtitle' => __('Input Button Menu Title, for menu on showcase page.', 'hera'),                        
                'default' => ''
            ),
            array(
                'id' => 'line_menu',
                'type' => 'media',
                'url' => false,
                'title' => __('Upload line menu', 'hera'),
                'compiler' => 'true',                
                'desc' => __('Upload your line menu, it is between items menu., Recommended size: 30px x 20px', 'hera'),
                'subtitle' => __('', 'hera'),
                'default' => array('url' => get_template_directory_uri().'/images/line.png'),
            ),
            array(
                'id' => 'colormenu',
                'type' => 'color',
                'title' => __('Menu Item Color', 'hera'),
                'subtitle' => __('Pick the menu item color for the theme (default: #000000).', 'hera'),                        
                'default' => '',
                'validate' => 'color',
            ),
            array(
                'id' => 'background_header',
                'type' => 'color',
                'title' => __('Background Header Static Color', 'hera'),
                'subtitle' => __('Pick the Background Header color for the theme (default: rgba(250,250,250,.9)).', 'hera'),                        
                'default' => '',
                'validate' => 'color',
            ),
            array(
                'id' => 'colormenu_scroll',
                'type' => 'color',
                'title' => __('Menu Item Scroll Color', 'hera'),
                'subtitle' => __('Pick the menu item scroll color for the theme (default: #000000).', 'hera'),                        
                'default' => '',
                'validate' => 'color',
            ),                                          
            array(
                'id' => 'background_header_scroll',
                'type' => 'color',
                'title' => __('Background Header Scroll Color', 'hera'),
                'subtitle' => __('Pick the Background Header Scroll color for the theme (default: rgba(250,250,250,.9)).', 'hera'),                        
                'default' => '',
                'validate' => 'color',
            ),  
        )
    ) );
    
    Redux::set_section( $opt_name, array(
        'icon' => 'el-icon-credit-card',
        'title' => __('Home Settings', 'hera'),
        'fields' => array(                                      
            array(
                'id' => 'menu_item1',
                'type' => 'text',
                'title' => __('Menu Item 1', 'hera'),
                'subtitle' => __('Input Menu Item', 'hera'),                        
                'default' => 'home'
            ),
            array(
                'id' => 'menu_item2',
                'type' => 'text',
                'title' => __('Menu Item 2', 'hera'),
                'subtitle' => __('Input Menu Item', 'hera'),                        
                'default' => 'about'
            ),
            array(
                'id' => 'menu_item3',
                'type' => 'text',
                'title' => __('Menu Item 3', 'hera'),
                'subtitle' => __('Input Menu Item', 'hera'),                        
                'default' => 'works'
            ),
            array(
                'id' => 'menu_item4',
                'type' => 'text',
                'title' => __('Menu Item 4', 'hera'),
                'subtitle' => __('Input Menu Item', 'hera'),                        
                'default' => 'services'
            ),
            array(
                'id' => 'menu_item5',
                'type' => 'text',
                'title' => __('Menu Item 5', 'hera'),
                'subtitle' => __('Input Menu Item', 'hera'),                        
                'default' => 'contact'
            ),
            array(
                'id' => 'menu_item6',
                'type' => 'text',
                'title' => __('Menu Item 6', 'hera'),
                'subtitle' => __('Input Menu Item', 'hera'),                        
                'default' => ''
            ),
            array(
                'id' => 'menu_item7',
                'type' => 'text',
                'title' => __('Menu Item 7', 'hera'),
                'subtitle' => __('Input Menu Item', 'hera'),                        
                'default' => ''
            ),
            array(
                'id' => 'menu_item8',
                'type' => 'text',
                'title' => __('Menu Item 8', 'hera'),
                'subtitle' => __('Input Menu Item', 'hera'),                        
                'default' => ''
            ),
            array(
                'id' => 'menu_item9',
                'type' => 'text',
                'title' => __('Menu Item 9', 'hera'),
                'subtitle' => __('Input Menu Item', 'hera'),                        
                'default' => ''
            ),
            array(
                'id' => 'menu_item10',
                'type' => 'text',
                'title' => __('Menu Item 10', 'hera'),
                'subtitle' => __('Input Menu Item', 'hera'),                        
                'default' => ''
            ),
            
        )
    ) );
    
    
    Redux::set_section( $opt_name, array(
        'icon' => 'el-icon-blogger',
        'title' => __('Blog Settings', 'hera'),
        'fields' => array( 
            array(
                'id'       => 'blog-layout',
                'type'     => 'image_select',
                'title'    => __( 'Blog Layout', 'hera' ),
                'subtitle' => __( 'Click on image layout to chooise', 'hera' ),
                'desc'     => __( 'Select layout you want use for all your blog page.', 'hera' ),
                'options'  => array(
                    '1' => array(
                        'alt' => '1 Column',
                        'img' => get_template_directory_uri().'/images/theme-options/1c.png'
                    ),                    
                    '2' => array(
                        'alt' => '2 Column Left',
                        'img' => get_template_directory_uri().'/images/theme-options/2cl.png'
                    ),    
                    '3' => array(
                        'alt' => '2 Column Right',
                        'img' => get_template_directory_uri().'/images/theme-options/2cr.png'
                    ),                                 
                ),
                'default'  => '3'
            ), 
            array(
                'id' => 'background-parallax-blog',
                'type' => 'media',
                'url' => false,
                'title' => __('Custom Background Parallax Blog', 'hera'),
                'compiler' => 'true',
                'desc' => __('Upload your Background Parallax Blog.', 'hera'),                
                'default' => array('url' => get_template_directory_uri().'/images/parallax-blog.jpg'),
            ),
            array(
                'id' => 'blog_title',
                'type' => 'text',
                'title' => __('Blog Title', 'hera'),
                'subtitle' => __('Input Blog Title', 'hera'),                
                'default' => 'Blog'
            ),
            array(
                'id' => 'blog_subtitle',
                'type' => 'text',
                'title' => __('Blog Sub Title', 'hera'),
                'subtitle' => __('Input Blog Sub Title', 'hera'),               
                'default' => 'Let us work with you to create online strategy that works.'
            ),             
            array(
                'id' => 'blog_excerpt',
                'type' => 'text',
                'title' => __('Excerpt Leght', 'hera'),
                'subtitle' => __('Input Excerpt Leght', 'hera'),                
                'default' => 30
            ),                                                                                          
        )
    ) );
        
    Redux::set_section( $opt_name, array(
        'icon' => 'el-icon-website',
        'title' => __('Styling Options', 'hera'),
        'fields' => array( 
            array(
                'id' => 'theme_style',
                'type' => 'select',
                'title' => __('Theme Style', 'hera'),
                'subtitle' => __('Select Theme Style : Dark Or Light', 'hera'),
                'desc' => __('Use Style Dark Or Style Light for full website.', 'hera'),
                'options'  => array(
                    'light' => 'Theme Style Light',
                    'dark' => 'Theme Style Dark',                            
                ),
                'default' => 'light',
            ),                   
            array(
                'id' => 'main_color',
                'type' => 'color',
                'title' => __('Theme Main Color', 'hera'),
                'subtitle' => __('Pick the main color for the theme (default: #cfa144).', 'hera'),
                'default' => '#cfa144',
                'validate' => 'color',
            ),  
            array(
                'id' => 'footer_color',
                'type' => 'color',
                'title' => __('Footer Text Background Color.', 'hera'),
                'subtitle' => __('Pick a background color for the footer text. (default: #a6a6a6).', 'hera'),
                'default' => '#a6a6a6',
                'validate' => 'color',
            ),  
            array(
                'id' => 'footer_bg',
                'type' => 'color',
                'title' => __('Footer Background Color', 'hera'),
                'subtitle' => __('Pick a background color for the footer (default: #292929).', 'hera'),
                'default' => '#292929',
                'validate' => 'color',
            ),              
            array(
                'id' => 'body-font2',
                'type' => 'typography',
                'output' => array('body'),
                'title' => __('Body Font', 'hera'),
                'subtitle' => __('Specify the body font properties.', 'hera'),
                'google' => true,
                'default' => array(
                    'color' => '',
                    'font-size' => '',
                    'line-height' => '',
                    'font-family' => '',
                    'font-weight' => ''
                ),
            ),
            array(
                'id' => 'custom-css',
                'type' => 'ace_editor',
                'title' => __('CSS Code', 'hera'),
                'subtitle' => __('Paste your CSS code here.', 'hera'),
                'mode' => 'css',
                'theme' => 'monokai',
                'desc' => 'Possible modes can be found.',
                'default' => ""
            ),
        )
    ) );

    /*
     * <--- END SECTIONS
     */


            